<?php
/**
 * Image Gallery Addon
 *
 * @package Radiantthemes
 */

namespace RadiantthemesAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Widget_Base;
use Elementor\Repeater;

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Image Gallery widget.
 *
 * Elementor widget that displays Image Gallery.
 *
 * @since 1.0.0
 */
class RadiantThemes_Style_Image_Gallery extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'radiant-image-gallery';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Image Gallery', 'radiantthemes-addons' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-group';
	}

	/**
	 * Requires css files.
	 *
	 * @return array
	 */
	public function get_style_depends() {
		return [
			'radiantthemes-addons-custom',
			'baguetteBox.min',
			'image-gallery-style',
			
		];
	}

	/**
	 * Requires js files.
	 *
	 * @return array
	 */
	public function get_script_depends() {
		return [
			'radiant-image-gallery',
		];
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'radiant-widgets-category' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'general_section',
			[
				'label' => esc_html__( 'General', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'image_gallery_style_variation',
			[
				'label'   => esc_html__( 'Image Gallery Style', 'radiantthemes-addons' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'one'   => esc_html__( 'Style One', 'radiantthemes-addons' ),
					'two'   => esc_html__( 'Style Two', 'radiantthemes-addons' ),
					
				],
				'default' => 'one',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'info_section',
			[
				'label' => esc_html__( 'Info', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'image_gallery_url',
			[
				'label'   => esc_html__( 'Add Images', 'plugin-domain' ),
				'type'    => Controls_Manager::GALLERY,
				'default' => [],
			]
		);

		$this->add_control(
			'item_small_gallery',
			[
				'label'       => esc_html__( 'Number of Items in small gallery', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::NUMBER,
				'default'     => 4,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_gallery',
			[
				'label' => esc_html__( 'Gallery', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label'    => esc_html__( 'Attachment Title Typography', 'radiantthemes-addons' ),
				'name'     => 'attachment_title_typography',
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' =>
					'{{WRAPPER}} .rt-image-gallery.element-one > .rt-image-gallery-holder .rt-image-gallery-item > .holder > .content h4',
				
			]
		);

		$this->add_control(
			'attachment_title_color',
			[
				'label'     => esc_html__( 'Attachment Title Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
				   	'{{WRAPPER}} .rt-image-gallery.element-one > .rt-image-gallery-holder .rt-image-gallery-item > .holder > .content h4' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-image-gallery.element-one > .rt-image-gallery-holder .rt-image-gallery-item > .holder > .content > .content-holder > .icon > span' => 'color: {{VALUE}}',
					
				],
			]
		);

		$this->add_control(
			'radiant_gallery_gradient_bg_type',
			[
				'label'       => esc_html__( 'Gallery Hover Gradient Background Type', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'to bottom'       => esc_html__( 'To Bottom', 'radiantthemes-addons' ),
					'to top'          => esc_html__( 'To Top', 'radiantthemes-addons' ),
					'to right'        => esc_html__( 'To Right', 'radiantthemes-addons' ),
					'to left'         => esc_html__( 'To Left', 'radiantthemes-addons' ),
					'to top left'     => esc_html__( 'To Top Left', 'radiantthemes-addons' ),
					'to bottom left'  => esc_html__( 'To Bottom Left', 'radiantthemes-addons' ),
					'to top right'    => esc_html__( 'To Top Right', 'radiantthemes-addons' ),
					'to bottom right' => esc_html__( 'To Bottom Right', 'radiantthemes-addons' ),
				],
				
				'description' => esc_html__( 'Select backgroud type.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_gallery_gradient_bg_color_one',
			[
				'label'     => esc_html__( 'Background Color (One)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
			
			]
		);

		$this->add_control(
			'radiant_gallery_gradient_bg_color_two',
			[
				'label'     => esc_html__( 'Background Color (Two)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-image-gallery.element-one > .rt-image-gallery-holder .rt-image-gallery-item > .holder > .overlay' => 'background: linear-gradient({{radiant_gallery_gradient_bg_type.VALUE}}, {{radiant_gallery_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
				],
				
			]
		);

		$this->end_controls_section();

	}


	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

		$output = '';
      	if ( 'one' === $settings['image_gallery_style_variation'] ) {
		$output .='<div class="rt-image-gallery element-one">
                    <div class="row rt-image-gallery-holder row isotope">';
       foreach ( $settings['image_gallery_url'] as $image ) {
					
				
                        $output .='<div class="rt-image-gallery-item web col-lg-4 col-md-4 col-sm-6 col-xs-12">
                            <div class="holder">
                                <div class="light-box-content">';
                                  	$output     .= '<img src="' . $image['url'] . '" alt="' . get_the_title( $image ) . '">';
                                $output .='</div>
                                <div class="overlay top-half"></div>
                                <div class="overlay bottom-half"></div>
                                <div class="content">
                                    <div class="content-holder">
                                        <div class="icon"> <span class="ti-plus"></span> </div>';
                                        $output .= '<h4>' . get_the_title( $image )  .get_the_title($image['id']) . '</h4>';
                                        $output .= '<p>' . wp_get_attachment_caption( $image ) . '</p>';
                                   $output .=' </div>
                                </div>';
                                $output .='<a class="pic-fancybox" href="' . $image['url'] . '" data-fancybox="images"></a>';
                            $output .='</div>
        				</div>'; 

          }
            $output .='</div>
        </div>';  
		}
		elseif ( 'two' === $settings['image_gallery_style_variation'] ) {
			$output .= '<div class="rt-image-gallery element-' . $settings['image_gallery_style_variation'] . '" data-thumbnail-items="' . $settings['item_small_gallery'] . '">';
			$output .= '<ul class="rt-image-gallery-holder owl-carousel">';
				foreach ( $settings['image_gallery_url'] as $image ) {
					$output .= '<li><img src="' . $image['url'] . '" alt="image-gallery"></li>';
				}
				$output .= '</ul>';
				$output .= '</div>';
			
		}

	echo $output;

	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _content_template() {

	}
}
