<?php
namespace RadiantthemesAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Color;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * @since 1.1.0
 */
class Radiantthemes_Style_Pricing_Table extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'radiant-pricing-table';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Pricing Table', 'radiantthemes-addons' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-price-table';
	}

	/**
	 * Requires css files.
	 *
	 * @return array
	 */
	public function get_style_depends() {
		return [
			'radiantthemes-addons-custom',
		];
	}

	/**
	 * Requires js files.
	 *
	 * @return array
	 */
	public function get_script_depends() {
		return [
			'radiantthemes-testimonial',
		];
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'radiant-widgets-category' ];
	}

	/**
	 * Get all Testimonial Custom Post Type Categories.
	 *
	 * @return array Testimonial categories.
	 */


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'general_section',
			[
				'label' => __( 'General', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'pricing_table_style_variation',
			[
				'label'   => __( 'Pricing Table Style', 'radiantthemes-addons' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'one',
				'options' => [
					'one'   => __( 'Style One', 'radiantthemes-addons' ),
					'two'  => __( 'Style Two', 'radiantthemes-addons' ),
					'three' => __( 'Style Three', 'radiantthemes-addons' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'info_section',
			[
				'label' => __( 'Info', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'pricing_table_image',
			[
				'label'     => __( 'Add Image (Eg. 80x80)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::MEDIA,

				'condition' => [
					'pricing_table_style_variation' => 'three',
				],

			]
		);
		$this->add_control(
			'pricing_table_image_five',
			[
				'label'     => __( 'Add Image (Eg. 80x80)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::MEDIA,

				'condition' =>
				[
					'pricing_table_style_variation' => 'five',
				],
			]
		);
		$this->add_control(
			'pricing_table_image_six',
			[
				'label'     => __( 'Add Image (Eg. 80x80)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::MEDIA,

				'condition' =>
				[
					'pricing_table_style_variation' => 'six',
				],
			]
		);
		$this->add_control(
			'pricing_table_image_seven',
			[
				'label'     => __( 'Add Image (Eg. 80x80)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::MEDIA,

				'condition' =>
				[
					'pricing_table_style_variation' => 'seven',
				],
			]
		);
		$this->add_control(
			'pricing_table_spotlight_text',
			[
				'label'     => __( 'Spotlight Text', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::TEXT,
				'default'     => __( 'Popular Choice', 'radiantthemes-addons' ),

				'condition' =>
				[
					'pricing_table_style_variation' => 'seven',
				],
			]
		);

		$this->add_control(
			'pricing_table_title',
			[
				'label'       => __( 'Title', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Basic Pack', 'radiantthemes-addons' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'pricing_table_subtitle',
			[
				'label'       => __( 'Subtitle', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( '', 'radiantthemes-addons' ),
				'label_block' => true,
				'condition' =>
				[
					'pricing_table_style_variation!' => 'one',
				],
			]
		);

		$this->add_control(
			'pricing_table_currency_symbol',
			[
				'label'       => __( 'Currency Symbol', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( '$', 'radiantthemes-addons' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'pricing_table_price',
			[
				'label'       => __( 'Price (Without Currency Symbol)', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( '199', 'radiantthemes-addons' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'pricing_table_period',
			[
				'label'       => __( 'Period', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Per Month', 'radiantthemes-addons' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'pricing_table_tagline',
			[
				'label'       => __( 'Tagline', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( '', 'radiantthemes-addons' ),
				'label_block' => true,
				'condition' =>
				[
					'pricing_table_style_variation!' => 'two',
				],

			]
		);

		$this->add_control(
			'content',
			[
				'label'      => __( 'Content', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::WYSIWYG,
				'default'    => __( 'Content', 'radiantthemes-addons' ),
				'show_label' => false,
			]
		);

		$this->add_control(
			'pricing_table_button',
			[
				'label'       => __( 'Button | Title', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Sign Up Now!', 'radiantthemes-addons' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'pricing_table_button_link',
			[
				'label'       => __( 'Button | Link', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'input_type'  => 'url',
				'placeholder' => __( 'https://your-link.com', 'radiantthemes-addons' ),
			]
		);

				$this->add_control(
			'radiant_price_btn_add_icon',
			[
				'label'        => esc_html__( 'Add Button icon?', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'radiantthemes-addons' ),
				'label_off'    => esc_html__( 'No', 'radiantthemes-addons' ),
				'return_value' => 'yes',
				'default'      => 'no',
			]
		);

		$this->add_control(
			'radiant_price_btn_icon_alignment',
			[
				'label'       => esc_html__( 'Icon Alignment', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'left'  => esc_html__( 'Left', 'radiantthemes-addons' ),
					'right' => esc_html__( 'Right', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_price_btn_add_icon' => 'yes',
				],
				'description' => esc_html__( 'Select icon alignment.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_price_btn_icon',
			[
				'label'     => esc_html__( 'Icons', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::ICON,
				'condition' => [
					'radiant_price_btn_add_icon' => 'yes',
				],
			]
		);


		$this->add_control(
			'pricing_table_highlight',
			[
				'label'        => __( 'Highlight ( If checked, item will be highlight By priority)', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'radiantthemes-addons' ),
				'label_off'    => __( 'Hide', 'radiantthemes-addons' ),
				'return_value' => 'spotlight',
				'default'      => 'spotlight',
			]
		);

		$this->add_control(
			'pricing_highlight_text',
			[
				'label'       => __( 'Highlight | Text', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Popular Choice', 'radiantthemes-addons' ),
				'label_block' => true,
				'condition' =>
				[
					'pricing_table_style_variation' => 'two',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Style', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' =>
				[
					'pricing_table_style_variation!' => 'eight',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => __( 'Title Typography', 'radiantthemes-addons' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' =>
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .heading .title, {{WRAPPER}} .rt-pricing-table > .holder > .heading .title, {{WRAPPER}} .rt-pricing-table.element-three > .holder > .heading .title',

			]
		);
		$this->add_control(
			'title_color',
			[
				'label'     => __( 'Title Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .heading .title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table > .holder > .heading .title'=> 'color: {{VALUE}}',


					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .heading .title' => 'color: {{VALUE}}',


					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .price,
					{{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .price sup,
					{{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .price sub,
					' => 'color: {{VALUE}}',

				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'subtitle_typography',
				'label'    => __( 'Sub Title Typography', 'radiantthemes-addons' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' =>
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .heading .subtitle, {{WRAPPER}} .rt-pricing-table.element-three > .holder > .heading .subtitle',


				'condition' =>
				[
					'pricing_table_style_variation!' => 'one',
				],

			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label'     => __( 'Sub Title Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
							'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .heading .subtitle'=> 'color: {{VALUE}}',
							'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .heading .subtitle'=> 'color: {{VALUE}}',
				],
				'condition' =>
				[
					'pricing_table_style_variation!' => 'one',
				],
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'price_typography',
				'label'    => __( 'Price Typography', 'radiantthemes-addons' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' =>
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .price,
					{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .price, {{WRAPPER}} .rt-pricing-table.element-two > .holder > .pricing .price, {{WRAPPER}} .rt-pricing-table.element-two > .holder > .pricing .price, {{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .price',

			]
		);
		$this->add_control(
			'price_color',
			[
				'label'     => __( 'Pricing Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
				  '{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .price' => 'color: {{VALUE}}',
				  '{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .price sup' => 'color: {{VALUE}}',

				  '{{WRAPPER}} .rt-pricing-table.element-two > .holder > .pricing .price,
				   {{WRAPPER}} .rt-pricing-table.element-two > .holder > .pricing .price sup' => 'color: {{VALUE}}',

				   '{{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .price' => 'color: {{VALUE}}',
				  '{{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .price sub' => 'color: {{VALUE}}',
				  '{{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .price sup' => 'color: {{VALUE}}',


				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'price_tag_typography',
				'label'    => __( 'Period Typography', 'radiantthemes-addons' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' =>
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .pricing-tag',
				'condition' =>
				[
					'pricing_table_style_variation' => 'one',
				],
			]
		);
		$this->add_control(
			'price_tag_background_color',
			[
				'label'     => __( 'Period Background Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
				  '{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .pricing-tag' => 'background-color: {{VALUE}}',
				],

				'condition' =>
				[
					'pricing_table_style_variation' => 'one',
				],
			]
		);
		$this->add_control(
			'price_tag_color',
			[
				'label'     => __( 'Period color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
				  '{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .pricing-tag' => 'color: {{VALUE}}',
				],

				'condition' =>
				[
					'pricing_table_style_variation' => 'one',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'price_tagline_typography',
				'label'    => __( 'Tagline Typography', 'radiantthemes-addons' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' =>
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .tagline, {{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .tagline',
				'condition' =>
				[
					'pricing_table_style_variation!' => 'two',
				],
			]
		);
		$this->add_control(
			'price_tagline_color',
			[
				'label'     => __( 'Tagline color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
				  '{{WRAPPER}} .rt-pricing-table.element-one > .holder > .pricing .tagline' => 'color: {{VALUE}}',
				  '{{WRAPPER}} .rt-pricing-table.element-three > .holder > .pricing .tagline' => 'color: {{VALUE}}',
				],

				'condition' =>
				[
					'pricing_table_style_variation!' => 'two',
				],
			]
		);
		/// Button ///
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'label'    => __( 'Button Typography', 'radiantthemes-addons' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' =>
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn,
					{{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn,
					{{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn',

			]
		);
		$this->add_control(
			'pricing_btn_text_color',
			[
				'label'     => esc_html__( 'Pricing Button Text Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn' => 'color: {{VALUE}}',


				],

			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => esc_html__( 'Border', 'radiantthemes-addons' ),
				'selector' => '{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn,
				        {{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn,
				        {{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn',

			/*	'condition' =>
				[
					'radiant_price_btn_gradient_bg_add!' => 'yes',
				],	*/
			]
		);
		$this->add_control(
			'radiant_price_btn_gradient_bg_add',
			[
				'label'        => esc_html__( 'Add Button Gradient Background?', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'your-plugin' ),
				'label_off'    => esc_html__( 'No', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'radiant_price_btn_gradient_bg_type',
			[
				'label'       => esc_html__( 'Gradient Background Type', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'to bottom'       => esc_html__( 'To Bottom', 'radiantthemes-addons' ),
					'to top'          => esc_html__( 'To Top', 'radiantthemes-addons' ),
					'to right'        => esc_html__( 'To Right', 'radiantthemes-addons' ),
					'to left'         => esc_html__( 'To Left', 'radiantthemes-addons' ),
					'to top left'     => esc_html__( 'To Top Left', 'radiantthemes-addons' ),
					'to bottom left'  => esc_html__( 'To Bottom Left', 'radiantthemes-addons' ),
					'to top right'    => esc_html__( 'To Top Right', 'radiantthemes-addons' ),
					'to bottom right' => esc_html__( 'To Bottom Right', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_price_btn_gradient_bg_add' => 'yes',

				],
				'description' => esc_html__( 'Select backgroud type.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_price_btn_gradient_bg_color_one',
			[
				'label'     => esc_html__( 'Background Color (One)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'radiant_price_btn_gradient_bg_add' => 'yes',

				],
			]
		);

		$this->add_control(
			'radiant_price_btn_gradient_bg_color_two',
			[
				'label'     => esc_html__( 'Background Color (Two)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn' => 'background: linear-gradient({{radiant_price_btn_gradient_bg_type.VALUE}}, {{radiant_price_btn_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn' => 'background: linear-gradient({{radiant_price_btn_gradient_bg_type.VALUE}}, {{radiant_price_btn_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn' => 'background: linear-gradient({{radiant_price_btn_gradient_bg_type.VALUE}}, {{radiant_price_btn_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',

				],
				'condition' => [
					'radiant_price_btn_gradient_bg_add' => 'yes',

				],
			]
		);
		$this->add_control(
			'pricing_btn_background_color',
			[
				'label'     => esc_html__( 'Pricing Button Background Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn' => 'background: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn' => 'background: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn' => 'background: {{VALUE}}',
				],

				'condition' =>
				[

					'radiant_price_btn_gradient_bg_add!' => 'yes',
				],

			]
		);
		$this->add_control(
			'radiant_price_btn_hover_gradient_bg_type',
			[
				'label'       => esc_html__( 'Hover Gradient Background Type', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'to bottom'       => esc_html__( 'To Bottom', 'radiantthemes-addons' ),
					'to top'          => esc_html__( 'To Top', 'radiantthemes-addons' ),
					'to right'        => esc_html__( 'To Right', 'radiantthemes-addons' ),
					'to left'         => esc_html__( 'To Left', 'radiantthemes-addons' ),
					'to top left'     => esc_html__( 'To Top Left', 'radiantthemes-addons' ),
					'to bottom left'  => esc_html__( 'To Bottom Left', 'radiantthemes-addons' ),
					'to top right'    => esc_html__( 'To Top Right', 'radiantthemes-addons' ),
					'to bottom right' => esc_html__( 'To Bottom Right', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_price_btn_gradient_bg_add' => 'yes',

				],
				'description' => esc_html__( 'Select backgroud type.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_price_btn_hover_gradient_bg_color_one',
			[
				'label'     => esc_html__( 'Hover Background Color (One)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'radiant_price_btn_gradient_bg_add' => 'yes',

				],
			]
		);

		$this->add_control(
			'radiant_price_btn_hover_gradient_bg_color_two',
			[
				'label'     => esc_html__( 'Hover Background Color (Two)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn:hover' => 'background: linear-gradient({{radiant_price_btn_gradient_bg_type.VALUE}}, {{radiant_price_btn_hover_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn:hover' => 'background: linear-gradient({{radiant_price_btn_gradient_bg_type.VALUE}}, {{radiant_price_btn_hover_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn:hover' => 'background: linear-gradient({{radiant_price_btn_gradient_bg_type.VALUE}}, {{radiant_price_btn_hover_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
				],
				'condition' => [
					'radiant_price_btn_gradient_bg_add' => 'yes',

				],
			]
		);
		$this->add_control(
			'pricing_btn_background_hover_color',
			[
				'label'     => esc_html__( 'Pricing Button Background Hover Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn:hover' => 'background: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn:hover' => 'background: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn:hover' => 'background: {{VALUE}}',
				],
					'condition' =>
				[

					'radiant_price_btn_gradient_bg_add!' => 'yes',
				],

			]
		);

		$this->add_control(
			'pricing_btn_hover_color',
			[
				'label'     => esc_html__( 'Pricing Button Hover Text Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn:hover' => 'color: {{VALUE}}',
					],

			]
		);


		$this->add_control(
			'radiant_pricing_btn_border_radius',
			[
				'label'      => esc_html__( 'Button Border Radius', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 35,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],

			]
		);
		/////
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'spotlight_text_typography',
				'label'    => __( 'Spotlight Text Typography', 'radiantthemes-addons' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' =>
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .spotlight-tag > .spotlight-tag-text',
				'condition' =>
				[
					'pricing_table_style_variation' => 'two',
					'pricing_table_highlight' => 'spotlight',
				],
			]

		);

$this->add_control(
			'spotlight_text_color',
			[
				'label'     => esc_html__( 'Pricing Spotlight Text Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .spotlight-tag > .spotlight-tag-text' => 'color: {{VALUE}}',

				],
				'condition' =>
				[
					'pricing_table_style_variation' => 'two',
					'pricing_table_highlight' => 'spotlight',
				],

			]
		);
$this->add_control(
			'spotlight_color',
			[
				'label'     => esc_html__( 'Pricing Spotlight Background Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .rt-pricing-table.element-two > .holder > .spotlight-tag > .spotlight-tag-text' => 'background: {{VALUE}}',
				],
				'condition' =>
				[
					'pricing_table_style_variation' => 'two',
					'pricing_table_highlight' => 'spotlight',
				],

			]
		);



	$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hover-border',
				'label' => esc_html__( 'Border', 'radiantthemes-addons' ),
				'selector' => '{{WRAPPER}} .rt-pricing-table.element-one > .holder > .more .btn:hover,
				        {{WRAPPER}} .rt-pricing-table.element-two > .holder > .more .btn:hover,
				        {{WRAPPER}} .rt-pricing-table.element-three > .holder > .more .btn:hover',

			/*	'condition' =>
				[
					'radiant_price_btn_gradient_bg_add!' => 'yes',
				],	*/
			]
		);







		$this->end_controls_section();

	}


	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {

		$settings         = $this->get_settings_for_display();

		echo '<!-- rt-pricing-table -->';
		echo '<div class="rt-pricing-table element-' . esc_html( $settings['pricing_table_style_variation'] ) . ' ' . $settings['pricing_table_highlight'] . '">';

		require __DIR__ . '/template/template-pricing-item-' . $settings['pricing_table_style_variation'] . '.php';

		echo '</div>' . "\r";
		echo '<!-- rt-pricing-table -->' . "\r";

		// ADD RADIANTTHEMES MAIN CSS.
			wp_register_style(
				'radiantthemes-addons-custom',
				plugins_url( 'css/radiantthemes-addons-custom.css', __FILE__ ),
				array(),
				time()
			);
			wp_enqueue_style( 'radiantthemes-addons-custom' );

	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _content_template() {

	}
}
